@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Conflicts;
 BEGIN {
-  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.06';
+  $Dist::Zilla::Plugin::Conflicts::VERSION = '0.07';
 }
 
 use strict;
@@ -83,7 +83,7 @@ sub register_prereqs {
 
     $self->zilla->register_prereqs(
         { phase => 'configure' },
-        'Dist::CheckConflicts' => '0.01',
+        'Dist::CheckConflicts' => '0.02',
     );
 }
 
@@ -156,12 +156,15 @@ sub _build_conflicts_file {
     );
 }
 
+# If dzil sees this string PODXXXX anywhere in this code it uses that as the
+# name for the module.
+my $podname_hack = 'POD' . 'NAME';
 my $script_template = <<'EOF';
 #!/usr/bin/perl
 
 use strict;
 use warnings;
-# PODNAME: {{ $filename }}
+# %s: {{ $filename }}
 
 use Getopt::Long;
 use {{ $module_name }};
@@ -178,6 +181,7 @@ else {
     exit @conflicts;
 }
 EOF
+$script_template = sprintf( $script_template, $podname_hack );
 
 sub _build_script {
     my $self = shift;
@@ -322,11 +326,11 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-{{ $filename }} - Declare conflicts for your distro
+Dist::Zilla::Plugin::Conflicts - Declare conflicts for your distro
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
